# eric7.EricWidgets

Package implementing some special widgets.

They extend or amend the standard widgets as found in QtWidgets.

### Modules

EricAnimatedLabel | Module implementing a label widget showing an animated pixmap.
EricAnimatedWidget | Module implementing an animated widget.
EricApplication | Class implementing a specialized application class.
EricAuthenticationDialog | Module implementing the authentication dialog for the help browser.
EricAutoResizeTextBrowser | Module implementing a QTextBrowser widget that resizes automatically.
EricClickableLabel | Module implementing a clickable label.
EricComboSelectionDialog | Module implementing a dialog to select one entry from a list of strings.
EricCompleters | Module implementing various kinds of completers.
EricDirFileDialog | Module implementing a dialog to select files and directories simultaneously.
EricErrorMessage | Module implementing a specialized error message dialog.
EricErrorMessageFilterDialog | Module implementing a dialog to manage the list of messages to be ignored.
EricFileDialog | Module implementing alternative functions for the QFileDialog static methods.
EricFileSaveConfirmDialog | Module implementing a dialog to enter a file system path using a file picker.
EricIconBar | Module implementing a bar widget showing just icons.
EricLed | Module implementing a LED widget.
EricLineEdit | Module implementing specialized line edits.
EricLineEditButton | Module implementing a button class to be used with EricLineEdit.
EricListSelectionDialog | Module implementing a dialog to select from a list of strings.
EricListView | Module implementing specialized list views.
EricMainWindow | Module implementing a main window class with styling support.
EricMapWidget | Module implementing a base class for showing a document map.
EricMessageBox | Module implementing QMessageBox replacements and more convenience function.
EricModelMenu | Module implementing a menu populated from a QAbstractItemModel.
EricModelToolBar | Module implementing a tool bar populated from a QAbstractItemModel.
EricPassivePopup | Module implementing dialog-like popup that displays messages without interrupting the user.
EricPasswordMeter | Module implementing a custom widget indicating the strength of a password.
EricPathPicker | Module implementing a path picker widget.
EricPathPickerDialog | Module implementing a dialog to enter a file system path using a file picker.
EricPlainTextDialog | Module implementing a dialog to show some plain text.
EricProcessDialog | Module implementing a dialog starting a process and showing its output.
EricProgressDialog | Module implementing a progress dialog allowing a customized progress bar label.
EricProxyStyle | Module implementing a proxy style to allow item selection by single/double click or platform default.
EricSideBar | Module implementing a sidebar class.
EricSimpleHelpDialog | Module implementing a dialog to show some help text.
EricSingleApplication | Module implementing the single application server and client.
EricSpellCheckedTextEdit | Module implementing QTextEdit and QPlainTextEdit widgets with embedded spell checking.
EricSqueezeLabels | Module implementing labels that squeeze their contents to fit the size of the label.
EricStretchableSpacer | Module implementing a stretchable spacer widget.
EricStringListEditWidget | Module implementing a dialog to edit a list of strings.
EricTabWidget | Module implementing a TabWidget class substituting QTabWidget.
EricTableView | Module implementing specialized table views.
EricTextEditSearchWidget | Module implementing a horizontal search widget for QTextEdit.
EricTextInputDialog | Module implementing a dialog to enter some text.
EricTextSpinBox | Module implementing a spinbox with textual entries.
EricToolBarDialog | Module implementing a toolbar configuration dialog.
EricToolBarManager | Module implementing a toolbar manager class.
EricToolBox | Module implementing a horizontal and a vertical toolbox class.
EricToolButton | Module implementing a specialized tool button subclass.
EricTreeView | Module implementing specialized tree views.
EricTreeWidget | Module implementing specialized tree views.
EricZoomWidget | Module implementing a zoom widget for the status bar.